SHELL       =  /bin/sh

CC          =  gcc
CXX         =  g++

DMTHOME     =  /opt/dmt
DMTVERSION  =  new

DMTINSTALL  =  $(DMTHOME)/$(DMTVERSION)

ROOTLIBDIR  = $(shell root-config --libdir)

RootCore    =  -L$(ROOTLIBDIR) -lCore -lCint

FCPPLIBS    =  -lframecpp -lgeneral -lz

FFTW3PATH   =  /usr

FFTW3LIBS   =  -L$(FFTW3PATH)/lib -lfftw3f -lz

INCDIRS     =  -I$(CURDIR) -I$(DMTINSTALL)/include -I$(FFTW3PATH)/include

DMTLIBS     =  -L$(DMTINSTALL)/lib -ldmtenv -lmonitor -losc -lframeio \
               -llmsg -ldmtsigp -lgdstrig -lgdscntr -lhtml -lxsil -lparsl \
               -lgdsbase $(FCPPLIBS) $(RootCore) $(FFTW3LIBS)
LDLIBS      =  $(DMTLIBS)

OPTIMIZE    =  3
CFLAGS      =  -Wall -O$(OPTIMIZE) $(INCDIRS) -g
CXXFLAGS    =  -Wall -O$(OPTIMIZE) $(INCDIRS) -g

LDFLAGS     =  -O$(OPTIMIZE)

INCLUDES    =  $(sort $(wildcard $(CURDIR)/*.h) $(wildcard $(CURDIR)/*.hh))
SOURCES     =  $(sort $(wildcard $(CURDIR)/*.c) $(wildcard $(CURDIR)/*.cc))
DEPENDS     =  $(addsuffix .d, $(basename $(SOURCES)))
OBJECTS     =  $(addsuffix .o, $(basename $(SOURCES)))

EXEC        =  DuoTone

.DELETE_ON_ERROR:

.PHONY:      all exec clean

all:         exec

exec:        $(EXEC)

$(EXEC):     $(OBJECTS)
	     $(CXX) $(LDFLAGS) -o $@ $(OBJECTS) $(LDLIBS)

clean:
	     -rm -f $(EXEC) > /dev/null 2>&1
	     -rm -f $(OBJECTS) > /dev/null 2>&1
	     -rm -f $(DEPENDS) > /dev/null 2>&1
	     -rm -f $(CURDIR)/*~ > /dev/null 2>&1
	     -rm -f $(CURDIR)/core > /dev/null 2>&1

INDEPENDENTS = clean

ifneq ($(strip $(filter-out $(INDEPENDENTS),$(MAKECMDGOALS))),)
-include $(DEPENDS)
endif

ifeq ($(strip $(MAKECMDGOALS)),)
-include $(DEPENDS)
endif

.SUFFIXES:
.SUFFIXES:   .c .cc .h .hh .o .d

%.d:         %.c
	     set -e; $(CC) -MM -MG $(CPPFLAGS) $(CFLAGS) $< \
             | sed 's/\($(*F)\)\.o[ :]*/\1.o $(@F) : /g' > $@; \
             [ -s $@ ] || rm -f $@ > /dev/null 2>&1

%.d:         %.cc
	     set -e; $(CXX) -MM -MG $(CPPFLAGS) $(CXXFLAGS) $< \
             | sed 's/\($(*F)\)\.o[ :]*/\1.o $(@F) : /g' > $@; \
             [ -s $@ ] || rm -f $@ > /dev/null 2>&1

