#ifndef TimingReader_HH
#define TimingReader_HH

#include "TimingTypes.hh"
#include "SigFlag.hh"

class LSMP_CON;

/** TimingReader.
    This class is used to read timing records from the shared memory.
    The function work does the heavy lifting and needs to be overriden.
    Look in TimingDump.cc for an example how to use this class.

    @memo TimingReader reads timing information from shared memory.
    @author Written September 2008 by Daniel Sigg
    @version 1.0
 ************************************************************************/
class TimingReader {
public:
   /// Constructor
   TimingReader (int argc, char* argv[]);
   /// Desctructor
   virtual ~TimingReader();
   /// Read the next timing data record from shared memory
   virtual void read (void);
   
   /// Returns true if the shared memory partition couldn't be opened
   bool operator! () const {
      return !mOpen; }
   /// Test termination flag
   bool term() const {
      return mTerm->test(); }
      
   /// Is help flag set?
   bool help() const {
      return mHelp; }
   /// Is debug flag set?
   bool debug() const {
      return mDebug; }
   
protected:
   /// Indicates if the open was successful
   bool			mOpen;
   /// Shared memory consumer
   LSMP_CON*		mCons;
   /// Buffer Id
   int 			mBufid;
   /// Termination signal flag pointer
   SigFlag*		mTerm;
   /// Help flag
   bool			mHelp;
   /// Debug flag
   bool			mDebug;
   
   /// Does the work! Needs to be overriden.
   virtual void work (const mfo_tree_list& mfolist) = 0;
   
   virtual bool init (int argc, char **argv);
   virtual void halt (void);
};

#endif //TimingReader_HH

