#include <errors.h>
#include <stdio.h>
#include <signal.h>

#ifdef _TIDG_
#include <tid.h>
#include <Time.hh>
#endif

using namespace std;

void HandleError (const string& err) // error handler
{
#ifdef _TIDG_
  Time now = Now();
  char tim[128];
  sprintf(tim,"%lu",now.getS());
#endif

  string s = string("ERROR(") +
    #ifdef _TIDG_
    tim + 
    string(") on ") + 
    tidg->GetsName() + 
    #else
    string(")") + 
    #endif
    string(": ") + err + string("\n");

  /*
  #ifdef _TIDG_
  // log error 
  if(tidg)
    tidg->AddComplain(s);
  #endif
  */

  // send error to error stream
  std::cerr<<s;


  if(strstr(s.c_str(),"FATAL")) {
    // fatal error, terminate process
    string tms("Fatal error: terminating process.");

    /*
#ifdef _TIDG_
    if(tidg)
      tidg->AddComplain(s);
#endif
    */

    cerr<<tms<<endl;

#ifdef _TIDG_
    if(!tidg->GetDMTBackground()) 
      raise(SIGTERM);
    else
      tidg->InterruptLoop();
#else
    raise(SIGTERM);
#endif
  }
}


void TidWarning (const string& msg) // warning handler
{
#ifdef _TIDG_
  Time now = Now();
  char tim[32];
  sprintf(tim,"%lu",now.getS());
#endif

  string s = string("WARNING(") +
#ifdef _TIDG_
    tim + 
    string(") from ") + string(tidg->GetsName()) + 
#else
    string(")") + 
#endif
    string(": ") + msg + string("\n");

  /*
#ifdef _TIDG_
  if(tidg)
    tidg->AddComplain(s);
#endif
  */

  std::cerr<<s;

}


void TidMessage (const string& msg) // message handler
{
#ifdef _TIDG_
  Time now = Now();
  char tim[32];
  sprintf(tim,"%lu",now.getS());
#endif

  string s = string("MESSAGE(") + 
#ifdef _TIDG_
    tim + 
    string(") from ") + string(tidg->GetsName()) + 
#else
    string(")") + 
#endif
    string(": ") + msg + string("\n");

  /*
#ifdef _TIDG_
  // log message
  if(tidg)
    tidg->AddMessage(s);
#endif
  */

  std::cout<<s;

}


void TidMessage(char const *s) 
{
  TidMessage(string(s));
}

void TidWarning(char const *s) 
{
  TidWarning(string(s));
}

void HandleError(char const *s)
{
  HandleError(string(s));
}
